@@ -1,12 +1,14 @@
 import json
+from collections.abc import Iterable
 from datetime import timedelta
-from typing import Optional, Type, Union
+from typing import Any, Dict, Optional, Type, Union
 
 import jwt
 from django.utils.translation import gettext_lazy as _
 from jwt import InvalidAlgorithmError, InvalidTokenError, algorithms
 
 from .exceptions import TokenBackendError
+from .tokens import Token
 from .utils import format_lazy
 
 try:
@@ -32,15 +34,15 @@ ALLOWED_ALGORITHMS = {
 class TokenBackend:
     def __init__(
         self,
-        algorithm,
-        signing_key=None,
-        verifying_key="",
-        audience=None,
-        issuer=None,
-        jwk_url: str = None,
-        leeway: Union[float, int, timedelta] = None,
+        algorithm: str,
+        signing_key: Optional[str] = None,
+        verifying_key: str = "",
+        audience: Union[str, Iterable, None] = None,
+        issuer: Optional[str] = None,
+        jwk_url: Optional[str] = None,
+        leeway: Union[float, int, timedelta, None] = None,
         json_encoder: Optional[Type[json.JSONEncoder]] = None,
-    ):
+    ) -> None:
         self._validate_algorithm(algorithm)
 
         self.algorithm = algorithm
@@ -57,7 +59,7 @@ class TokenBackend:
         self.leeway = leeway
         self.json_encoder = json_encoder
 
-    def _validate_algorithm(self, algorithm):
+    def _validate_algorithm(self, algorithm: str) -> None:
         """
         Ensure that the nominated algorithm is recognized, and that cryptography is installed for those
         algorithms that require it
@@ -91,7 +93,7 @@ class TokenBackend:
                 )
             )
 
-    def get_verifying_key(self, token):
+    def get_verifying_key(self, token: Token) -> Optional[str]:
         if self.algorithm.startswith("HS"):
             return self.signing_key
 
@@ -103,7 +105,7 @@ class TokenBackend:
 
         return self.verifying_key
 
-    def encode(self, payload):
+    def encode(self, payload: Dict[str, Any]) -> str:
         """
         Returns an encoded token for the given payload dictionary.
         """
@@ -125,7 +127,7 @@ class TokenBackend:
         # For PyJWT >= 2.0.0a1
         return token
 
-    def decode(self, token, verify=True):
+    def decode(self, token: Token, verify: bool = True) -> Dict[str, Any]:
         """
         Performs a validation of the given token and returns its payload
         dictionary.
