@@ -1,3 +1,5 @@
+from typing import Any, Dict, Optional, Union
+
 from django.utils.translation import gettext_lazy as _
 from rest_framework import exceptions, status
 
@@ -11,7 +13,14 @@ class TokenBackendError(Exception):
 
 
 class DetailDictMixin:
-    def __init__(self, detail=None, code=None):
+    default_detail: str
+    default_code: str
+
+    def __init__(
+        self,
+        detail: Union[Dict[str, Any], str, None] = None,
+        code: Optional[str] = None,
+    ) -> None:
         """
         Builds a detail dictionary for the error to give more information to API
         users.
@@ -26,7 +35,7 @@ class DetailDictMixin:
         if code is not None:
             detail_dict["code"] = code
 
-        super().__init__(detail_dict)
+        super().__init__(detail_dict)  # type: ignore
 
 
 class AuthenticationFailed(DetailDictMixin, exceptions.AuthenticationFailed):
