@@ -1,19 +1,24 @@
+from typing import Any, Dict, Optional, Type, TypeVar
+
 from django.conf import settings
 from django.contrib.auth import authenticate, get_user_model
-from django.contrib.auth.models import update_last_login
+from django.contrib.auth.models import AbstractBaseUser, update_last_login
 from django.utils.translation import gettext_lazy as _
 from rest_framework import exceptions, serializers
 from rest_framework.exceptions import ValidationError
 
+from .models import TokenUser
 from .settings import api_settings
-from .tokens import RefreshToken, SlidingToken, UntypedToken
+from .tokens import RefreshToken, SlidingToken, Token, UntypedToken
+
+AuthUser = TypeVar("AuthUser", AbstractBaseUser, TokenUser)
 
 if api_settings.BLACKLIST_AFTER_ROTATION:
     from .token_blacklist.models import BlacklistedToken
 
 
 class PasswordField(serializers.CharField):
-    def __init__(self, *args, **kwargs):
+    def __init__(self, *args, **kwargs) -> None:
         kwargs.setdefault("style", {})
 
         kwargs["style"]["input_type"] = "password"
@@ -24,19 +29,19 @@ class PasswordField(serializers.CharField):
 
 class TokenObtainSerializer(serializers.Serializer):
     username_field = get_user_model().USERNAME_FIELD
-    token_class = None
+    token_class: Optional[Type[Token]] = None
 
     default_error_messages = {
         "no_active_account": _("No active account found with the given credentials")
     }
 
-    def __init__(self, *args, **kwargs):
+    def __init__(self, *args, **kwargs) -> None:
         super().__init__(*args, **kwargs)
 
-        self.fields[self.username_field] = serializers.CharField()
+        self.fields[self.username_field] = serializers.CharField(write_only=True)
         self.fields["password"] = PasswordField()
 
-    def validate(self, attrs):
+    def validate(self, attrs: Dict[str, Any]) -> Dict[Any, Any]:
         authenticate_kwargs = {
             self.username_field: attrs[self.username_field],
             "password": attrs["password"],
@@ -57,14 +62,14 @@ class TokenObtainSerializer(serializers.Serializer):
         return {}
 
     @classmethod
-    def get_token(cls, user):
-        return cls.token_class.for_user(user)
+    def get_token(cls, user: AuthUser) -> Token:
+        return cls.token_class.for_user(user)  # type: ignore
 
 
 class TokenObtainPairSerializer(TokenObtainSerializer):
     token_class = RefreshToken
 
-    def validate(self, attrs):
+    def validate(self, attrs: Dict[str, Any]) -> Dict[str, str]:
         data = super().validate(attrs)
 
         refresh = self.get_token(self.user)
@@ -81,7 +86,7 @@ class TokenObtainPairSerializer(TokenObtainSerializer):
 class TokenObtainSlidingSerializer(TokenObtainSerializer):
     token_class = SlidingToken
 
-    def validate(self, attrs):
+    def validate(self, attrs: Dict[str, Any]) -> Dict[str, str]:
         data = super().validate(attrs)
 
         token = self.get_token(self.user)
@@ -99,7 +104,7 @@ class TokenRefreshSerializer(serializers.Serializer):
     access = serializers.CharField(read_only=True)
     token_class = RefreshToken
 
-    def validate(self, attrs):
+    def validate(self, attrs: Dict[str, Any]) -> Dict[str, str]:
         refresh = self.token_class(attrs["refresh"])
 
         data = {"access": str(refresh.access_token)}
@@ -127,7 +132,7 @@ class TokenRefreshSlidingSerializer(serializers.Serializer):
     token = serializers.CharField()
     token_class = SlidingToken
 
-    def validate(self, attrs):
+    def validate(self, attrs: Dict[str, Any]) -> Dict[str, str]:
         token = self.token_class(attrs["token"])
 
         # Check that the timestamp in the "refresh_exp" claim has not
@@ -142,9 +147,9 @@ class TokenRefreshSlidingSerializer(serializers.Serializer):
 
 
 class TokenVerifySerializer(serializers.Serializer):
-    token = serializers.CharField()
+    token = serializers.CharField(write_only=True)
 
-    def validate(self, attrs):
+    def validate(self, attrs: Dict[str, None]) -> Dict[Any, Any]:
         token = UntypedToken(attrs["token"])
 
         if (
@@ -159,10 +164,10 @@ class TokenVerifySerializer(serializers.Serializer):
 
 
 class TokenBlacklistSerializer(serializers.Serializer):
-    refresh = serializers.CharField()
+    refresh = serializers.CharField(write_only=True)
     token_class = RefreshToken
 
-    def validate(self, attrs):
+    def validate(self, attrs: Dict[str, Any]) -> Dict[Any, Any]:
         refresh = self.token_class(attrs["refresh"])
         try:
             refresh.blacklist()
