@@ -1,4 +1,5 @@
 from datetime import timedelta
+from typing import Any, Dict
 
 from django.conf import settings
 from django.test.signals import setting_changed
@@ -41,6 +42,8 @@ DEFAULTS = {
     "TOKEN_BLACKLIST_SERIALIZER": "rest_framework_simplejwt.serializers.TokenBlacklistSerializer",
     "SLIDING_TOKEN_OBTAIN_SERIALIZER": "rest_framework_simplejwt.serializers.TokenObtainSlidingSerializer",
     "SLIDING_TOKEN_REFRESH_SERIALIZER": "rest_framework_simplejwt.serializers.TokenRefreshSlidingSerializer",
+    "CHECK_REVOKE_TOKEN": False,
+    "REVOKE_TOKEN_CLAIM": "hash_password",
 }
 
 IMPORT_STRINGS = (
@@ -59,7 +62,7 @@ REMOVED_SETTINGS = (
 
 
 class APISettings(_APISettings):  # pragma: no cover
-    def __check_user_settings(self, user_settings):
+    def __check_user_settings(self, user_settings: Dict[str, Any]) -> Dict[str, Any]:
         SETTINGS_DOC = "https://django-rest-framework-simplejwt.readthedocs.io/en/latest/settings.html"
 
         for setting in REMOVED_SETTINGS:
@@ -80,7 +83,7 @@ class APISettings(_APISettings):  # pragma: no cover
 api_settings = APISettings(USER_SETTINGS, DEFAULTS, IMPORT_STRINGS)
 
 
-def reload_api_settings(*args, **kwargs):  # pragma: no cover
+def reload_api_settings(*args, **kwargs) -> None:  # pragma: no cover
     global api_settings
 
     setting, value = kwargs["setting"], kwargs["value"]
