@@ -1,8 +1,8 @@
 from datetime import datetime, timedelta
-from unittest.mock import patch
 
 from django.test import TestCase
 from django.utils import timezone
+from freezegun import freeze_time
 
 from rest_framework_simplejwt.utils import (
     aware_utcnow,
@@ -34,11 +34,9 @@ class TestMakeUtc(TestCase):
 
 class TestAwareUtcnow(TestCase):
     def test_it_should_return_the_correct_value(self):
-        now = datetime.utcnow()
-
-        with patch("rest_framework_simplejwt.utils.datetime") as fake_datetime:
-            fake_datetime.utcnow.return_value = now
+        now = datetime.now(tz=timezone.utc).replace(tzinfo=None)
 
+        with freeze_time(now):
             # Should return aware utcnow if USE_TZ == True
             with self.settings(USE_TZ=True):
                 self.assertEqual(
